@@ -4,7 +4,11 @@
 // Defines determined during configuration of m4ri.
 #define __M4RI_HAVE_MM_MALLOC		1
 #define __M4RI_HAVE_POSIX_MEMALIGN	1
-#define __M4RI_HAVE_SSE2		(defined(__SSE2__) && __SSE2__)
+#define __M4RI_HAVE_SSE2		0
+#if 1 && defined(__SSE2__) && __SSE2__
+#undef __M4RI_HAVE_SSE2
+#define __M4RI_HAVE_SSE2		1
+#endif
 #define __M4RI_HAVE_OPENMP		1
 #define __M4RI_CPU_L1_CACHE		32768
 #define __M4RI_CPU_L2_CACHE		1048576
@@ -25,4 +29,9 @@
 #define __M4RI_ENABLE_MZD_CACHE         0
 #define __M4RI_ENABLE_MMC               0
 
+#if defined(__MINGW32__) || defined(__MINGW64__)
+#define random rand
+#define srandom srand
+#endif
+
 #endif // M4RI_M4RI_CONFIG_H
